@@ -18,14 +18,14 @@
 
 #include "kgtheme.h"
 
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtCore/QStandardPaths>
+#include <QDir>
+#include <QFileInfo>
+#include <QStandardPaths>
 
 #include <KConfig>
 #include <KConfigGroup>
 
-Q_LOGGING_CATEGORY(GAMES_LIB, "games.lib")
+Q_LOGGING_CATEGORY(GAMES_LIB, "org.kde.games.lib", QtWarningMsg)
 
 class KgTheme::Private
 {
@@ -45,7 +45,6 @@ KgTheme::KgTheme(const QByteArray& identifier, QObject* parent)
 	: QObject(parent)
 	, d(new Private(identifier))
 {
-    QLoggingCategory::setFilterRules(QStringLiteral("games.lib.debug = true"));
 }
 
 KgTheme::~KgTheme()
@@ -95,7 +94,7 @@ bool KgTheme::readFromDesktopFile(const QString& path_)
 	QString path(path_);
 	if (QFileInfo(path).isRelative())
 	{
-		path = QStandardPaths::locate(QStandardPaths::DataLocation, path);
+		path = QStandardPaths::locate(QStandardPaths::AppDataLocation, path);
 		if (path.isEmpty())
 		{
 			qCDebug(GAMES_LIB) << "Could not find theme description" << path;
