@@ -196,7 +196,7 @@ void KGameSvgDocument::load()
     QByteArray content = file.readAll();
 
     // If the file is compressed, decompress the contents before loading it.
-    if (!content.startsWith("<?xml"))
+    if (!content.startsWith("<?xml")) // krazy:exclude=strings
     {
         QBuffer buf(&content);
         KCompressionDevice::CompressionType type = KFilterDev::compressionTypeForMimeType(QStringLiteral("application/x-gzip"));
@@ -287,7 +287,7 @@ void KGameSvgDocument::scale(double xFactor, double yFactor, const MatrixOptions
     QMatrix matrix;
     if ((xFactor == 0) || (yFactor == 0))
     {
-        qWarning () << "KGameSvgDocument::scale: You cannnot scale by zero";
+        qWarning () << "KGameSvgDocument::scale: You cannot scale by zero";
     }
 
     if (options == ApplyToCurrentMatrix)
